function revents = RGevents(subjectno, session, dataroot)
%
% REVENTS - creates recognition events structure
%
% Creates recognition events structure for one subject using information
% from word pool file and log file.
%
% FUNCTION:
%   revents = RGevents(subjectno, session, dataroot)
%
% INPUT ARGS: 
%   subject: subject identification
%   session: session number
%   dataroot: directory of where the data is located
%
% OUTPUT ARGS: events structure with the following fields
%                 FIELDS: 1) subject = subject number
%                         2) session = subject session
%                         3) type    = event type (ex. 'RECOG_START', 'RECOG_RESP')
%                         4) item    = event item (the word presented )
%                         5) list    =  list target was presented in during the free recall portion
%                         6) mstime = time each event occurs during recognition task        
%                         7) msoffset = positive offset from mstime (the event must occur betweet mstime ad mstime + msoffset)
%                         8) class = type of recognition response(Hit - H, False Alarm - FA, Miss - M,  Correct Rejection - CR)   
%                         9) rxntime - the reaction time of recognition response             
%                        10) rxnt_offset - reaction time offset
%                        11) istarget - is the item a target (1 if yes, 0 if no and is a rule)
%                        12) original_presT - the time target was presented during free recall interval
%                        13) recalled - was the presented target recalled in the free recall portion
%
% SAMPLE INPUTS:
%  
%    clear all;
%    subjectno = 'FR010';
%    session = 3;
%    dataroot = '/Users/vitaly/Desktop/data/'


% read in words presented into a matrix
trials = 16; %  HARDCODED FOR NOW!!!!!!

fr_words = [];
for lis=1:trials
        var =fullfile(dataroot,[num2str(lis-1) '.lst' ]);
        words = textread (var , '%s');
        fr_words = [fr_words;  words'];
end

% create events structure
RGlogfile = fullfile(dataroot,'recognition.log');
event = struct('subject', [], 'session', [], 'list', [], 'type', [], 'mstime', [], 'msoffset', [], 'item', [], 'class', [], 'rxntime',[] , 'rxnt_offset', [], 'istarget', [], 'original_presT', [], 'recalled', []  );
[time, msoffset, type, key_text, word_rxntime, istarget_offset] = textread(RGlogfile , '%s%s%s%s%s%s' , 'emptyvalue',  NaN );

revents = repmat(event,1,length(type));

% go through each event time spot and fill up structure
for e=1:length(type)
% set default values
revents(e).subject =subjectno;
revents(e).session = session;
revents(e).list = -999;
revents(e).type = type{e};
revents(e).mstime = str2num(time{e});
revents(e).msoffset = str2num(msoffset{e});
revents(e).item = 'X'; 
revents(e).class = 'X';
revents(e).rxntime = -999;
revents(e).rxnt_offset = -999;
revents(e).istarget = -999;
revents(e).original_presT = -999;
revents(e).recalled = -999;
    
  switch type{e}
      
      case {'REC_START'}
      % nuttin happens        
      case {'RECOG_START'}
      % nuttin happens
      
      % word presentation
      case {'RECOG_PRES'}
        revents(e).item = word_rxntime{e};
        revents(e).istarget = str2num(istarget_offset{e});
    
        if revents(e).istarget == 1
             [x,y] =   find(strcmp(revents(e).item, fr_words)) ;
             % assign the list the word was originally presented into the recognition events structure
             revents(e).list = x;
        end
        
       % key response
       case{'RECOG_RESP'}
           
        revents(e-1).item = word_rxntime{e -1};   
        revents(e).item = word_rxntime{e -1};
        
        revents(e-1).rxntime =   str2num(word_rxntime{e});
        revents(e).rxntime =   str2num(word_rxntime{e});
        
        
        revents(e-1).rxnt_offset =   str2num(istarget_offset{e});
        revents(e).rxnt_offset   =     str2num(istarget_offset{e});
       
        
        revents(e).istarget=str2num(istarget_offset{e-1});
        
              if strcmp( key_text(e), 'Z')         & strcmp( istarget_offset(e-1), '0')
                  revents(e-1).class = 'CR'; %for the presented word
                  revents(e).class = 'CR';     %Correct Rejection     
                  
              elseif strcmp( key_text(e), 'Z')   &  strcmp( istarget_offset(e-1), '1')
                  revents(e-1).class = 'M'; 
                  revents(e).class = 'M'; 
                 % Miss
              elseif  strcmp( key_text(e), '/')   &  strcmp( istarget_offset(e-1), '0')
                  revents(e-1).class = 'FA';   
                  revents(e).class = 'FA';     %False Alarm
                  
              elseif strcmp( key_text(e), '/')   &  strcmp( istarget_offset(e-1), '1')
                  revents(e-1).class = 'H';       % Hit
                  revents(e).class = 'H';       % Hit
                  
              end        
                     
        % assign the list the word was originally presented into the
        % recognition events structure
        if str2num(istarget_offset{e-1}) == 1
              revents(e).list = x;
       end
                        
              
    end
              
end

