function create_beh_events(subject,session,datadir,wordpool,wordfreq)
%CREATE_BEH_EVENTS - Generate the behavioral events from logs
%
%
% FUNCTION:
%   create_beh_events(subject,session,datadir,wordpool,wordfreq)
%
% INPUT ARGS:
%   subject = 'FR001';  % Subject ID
%   session = 1;        % Session ID (Note this is one-based)
%   datadir = '../data'; % Base dir containing subj data (Default Shown)
%   wordpool = '../pools/word-pool.txt';  % Word pool to use
%                                         % (Default Shown)
%   wordfreq = '../pools/word_freq.txt';  % Word freq matching word
%                                         % pool (Default Shown)
%


% process args
if ~exist('datadir','var')
  datadir = '../data';
end
if ~exist('wordpool','var')
  wordpool = '../pools/word-pool.txt';
end
if ~exist('wordfreq','var')
  wordfreq = '../pools/word_freq.txt';
end

% set up directory paths
subjdir = fullfile(datadir,subject);
sessdir = fullfile(subjdir,['session_' num2str(session-1) '/']);


% Create the FR events
fprintf('Creating FR events...');
logfile = fullfile(sessdir,'session.log');
zerobased = 0;
headlines = 0;
events = makeFRevents(subject,session,logfile,wordpool,zerobased,sessdir,headlines);
fprintf('Done\n');

% Create the recog events
fprintf('Creating RG events...');
revents = RGevents(subject,session,datadir);
fprintf('Done\n')

% use data from each of the structures to modify each other
fprintf('Unifying FR and RG...')
[events, revents] = unifyFRandRG(events, revents);
fprintf('Done\n');

% add in the freq info if provided
if ~isempty(wordfreq)
  fprintf('Adding freq info...');
  [events, revents] = events_wf_mod(events, revents, wordfreq);
  fprintf('Done\n');
end

% save everything out to the session directory
fprintf('Saving events to the session directory...');
eventsfile = fullfile(sessdir,'events.mat');
reventsfile = fullfile(sessdir,'revents.mat');

saveEvents(events,eventsfile);
saveEvents(revents,reventsfile);

fprintf('Done!!!\n');

