function [events, revents] = events_wf_mod(events, revents, path)
%
% *****HELPER FUNCTION*****
%
% EVENTS_WF_MOD - adds wf fields to the events and revents structure
%
% This function will modify the events structure created with post_process
% and save a new events structure that contains a kw_word_freq field (this 
% field contains the Kuchera-Francis written frequency values).  
%
%
% FUNCTION: 
%   [events, revents] = events_wf_mod(events, revents, path)
%
% INPUT ARGS:
%   events - fr events structure
%   revents - recognition events structure
%   path    - is the path to the word frequency file
%             ex. '/Users/lynne/FRdata/word_freq.txt)
%
% OUTPUT ARGS: 
%   events - modified events
%   revents - modified revents

% read in the list of word frequencies
freq = textread(path, '%*s%n');
wordpool = textread(path, '%s%*n'); % read in the word pool from the word_freq file

% go through free recall events structure
for e = 1:length(events)
  if events(e).itemno > 0 
    % reads the frequency value of the itemno
    events(e).kw_freq = freq(events(e).itemno);
  else 
    % sets the default to -999
    events(e).kw_freq = -999;
  end
end
        
% go through recognition events structure
for e = 1:length(revents)
  if strcmp(revents(e).type, 'RECOG_PRES') | strcmp(revents(e).type, 'RECOG_RESP') == 1
     % since there is no itemno field in the recognition events structure, we
     % need to find the item number.
     item_no = find(strcmp(revents(e).item, wordpool));
     revents(e).kw_freq = freq(item_no);
  else
     revents(e).kw_freq = -999;
  end   
end
