function [events, revents] = unifyFRandRG(events, revents) 
% 
% ****HELPER FUNCTION****
%
% EVENTS_MOD - modifies the free recall and recognition events structures
%
%   1) fills in the recognition function when
%   the targets were last presented and wether the targets where recalled or notThis to be done for one subject's
%   2) fills in the free recall function whether targets are 
%    later missed (0) or hit(1)session only. 
%   This function will be part of the post processing script
%
%
% FUNCTION:  
%   [events , revents] = frevents_mod(revents, events) 
%
% INPUT ARGS:  
%   events  -  events structure - 1 session only
%   revents - revents structure  - 1 session only
%
% OUTPUT ARGS: 
%   events - modified free recall events struct
%   revents  - modified recognition events structure

% recalled events
rec_e = filterStruct(events, 'recalled==1');
rec_items = getStructField(rec_e, 'item');

% not recalled events
nrec_e = filterStruct(events, 'recalled==0');
nrec_items = getStructField(nrec_e, 'item');


% MODIFY REVENTS
% go through the REVENTS structure and fill up unfilled fields
% using info from the free recall events structure
for e=1:length(revents)
   % if the presented word during the recognition task is a target
    if revents(e).istarget ==1
    
        % if the target was previously recalled
        if (find(strcmp(revents(e).item, rec_items)))
            % location in the events structure in which the item is found
            r_loc = find(strcmp(revents(e).item, rec_items));
            revents(e).recalled = 1;
            revents(e).original_presT = rec_e(r_loc).mstime; % the time in which the word was presented
        end 
        
        % if the target was not previously recalled
        if (find(strcmp(revents(e).item, nrec_items)))
            % location in the events structure in which the item is found
            nr_loc = find(strcmp(revents(e).item, nrec_items));
            revents(e).recalled = 0;
            revents(e).original_presT = nrec_e(nr_loc).mstime ;% the time in which the word was presented
        end   
    end
end


% MODIFY FREE RECALL EVENTS STRUCTURE
for x=1:length(events)
    events(x).recog = -999;
end

% get Hits and Misses from the recognition events struct
H = getStructField (revents,  'item' ,  [' strcmp (class, ''H'') '] );
M = getStructField (revents , 'item' ,  [' strcmp (class, ''M'') '] );

% go through Hits and for each presnted word designate in the free 
% recall structure whether the word was later recognized 
for x=1:length(H)
    loc = find( strcmp( H{x}, getStructField(events, 'item')));
    events(loc(1)).recog = 1;
end

% go through Misses and for each presnted word designate in the free 
% recall structure whether the word was later not recognized 
for x=1:length(M)
    loc = find( strcmp( M{x}, getStructField(events, 'item')));
    events(loc(1)).recog = 0;
end




